/virtualbox/{uuid}/stop — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /virtualbox/{uuid}/stop

Contents

- /virtualbox/{uuid}/stop
  - POST /virtualbox/{uuid}/stop
    - Parameters
    - Response status codes
    - Sample session

## POST /virtualbox/{uuid}/stop

Stop a VirtualBox VM instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 400: Invalid instance UUID
- 404: Instance doesn’t exist
- 204: Instance stopped

### Sample session

    curl -i -X POST 'http://localhost:8000/virtualbox/{uuid}/stop' -d '{}'

    POST /virtualbox/{uuid}/stop HTTP/1.1
    {}

    HTTP/1.1 204
    CONNECTION: close
    CONTENT-LENGTH: 0
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 aiohttp/0.13.1
    X-ROUTE: /virtualbox/{uuid}/stop

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »